@@ -8,6 +8,6 @@ from .board import create_board, boards, get_board, results
 import jiggy.jiggyboard.jb_wandb as wandb    
     
 
-def init():
-    wandb.jb_wandb_init()
+def setup():
+    wandb.jb_wandb_setup()
     
