@@ -3,8 +3,10 @@
 #
 
 from os import environ
+from getpass import getpass
 import wandb
 
+
 from ..login import window_open
 from ..user import authenticated_user, all_teams, Team
 from .artifact_source import ArtifactService, ArtifactSource, ArtifactSourceRequest, artifact_sources
@@ -32,7 +34,7 @@ def create_artifact_source(team    : Team = None,
     if not api_key:
         # prompt user for wandb key
         window_open("https://%s/authorize" % host.split('.',1)[1])
-        api_key = input("Enter your wandb.ai API Key: ")
+        api_key = getpass("Enter your wandb.ai API Key: ")
     # api key validation will occur server side
     rsp = session.post(f'/teams/{team_id}/artifact_sources', model=ArtifactSourceRequest(host    = host,
                                                                                          api_key = api_key,
@@ -79,7 +81,7 @@ def jb_wandb_setup():
         for c in atype.collections():
             cname = f"{c.entity}/{c.project}/{c.name}"
             collections.append(cname)
-            print(f" {count:2}: {atype.name+':':12}   {cname}")
+            print(f" {count:2}: {atype.name+':':16} '{cname}'")
             count += 1
                 
     def setup_watcher(jiggy_type):
@@ -95,16 +97,18 @@ def jb_wandb_setup():
                 pass
         board.create_artifact_watcher(wandb_store, jiggy_type,  artifact)
 
-    setup_watcher('model')
-    setup_watcher('dataset')
-    setup_watcher('code')
+    configured_watchers = set([w.jiggy_type for w in board.artifact_watchers()])
+    REQUIRED_WATCHERS = set(['model','dataset','code'])
+    needed_watchers = REQUIRED_WATCHERS - configured_watchers
+    for jiggy_type in list(needed_watchers):
+        setup_watcher(jiggy_type)
 
     print("\nThe following watchers are configured:")
     for w in board.artifact_watchers():
         print(f"{w.jiggy_type:8} {w.name}")
 
     configured_watchers = set([w.jiggy_type for w in board.artifact_watchers()])
-    needed_watchers = set(['model','dataset','code']) - configured_watchers
+    needed_watchers = REQUIRED_WATCHERS - configured_watchers
     if needed_watchers:
         print(f"\nNotice: The following watcher types must still be configured for a functional leaderboard: {needed_watchers}\n")
 
